@@ -281,17 +281,21 @@ MakeADFun <- function(data, parameters, map=list(),
     keepAttrib( parameters[names(map)] ) <- param.map
   }
 
+  lrandom <- function() {
+      ans <- logical(length(par))
+      ans[random] <- TRUE
+      ans
+  }
+  lfixed <- function() {
+      !lrandom()
+  }
   ## Utility to get back parameter list in original shape
-  parList <- function(x=par[-random],par=last.par){
+  parList <- function(x=par[lfixed()],par=last.par){
     ans <- parameters
     nonemp <- sapply(ans,function(x)length(x)>0) ## Workaround utils::relist bug for empty list items
     nonempindex <- which(nonemp)
     skeleton <- as.relistable(ans[nonemp])
-    if(any(random)){
-      par[-random] <- x
-    } else {
-      par[] <- x
-    }
+    par[lfixed()] <- x
     li <- relist(par,skeleton)
     reshape <- function(x){
       if(is.null(attr(x,"map")))return(x)
@@ -1018,6 +1022,9 @@ compile <- function(file,flags="",safebounds=TRUE,safeunload=TRUE,
       chartr("\\", "/", shortPathName(ans))
     }
   }
+  qsystem.file <- function(...) {
+      paste0('"', system.file(...), '"')
+  }
   ## Cannot use the pre-compiled library when enabling sweep tracing
   if (tracesweep) libtmb <- FALSE
   ## libtmb existence
@@ -1080,9 +1087,9 @@ compile <- function(file,flags="",safebounds=TRUE,safeunload=TRUE,
   ## Includes and preprocessor flags specific for the template
   useRcppEigen <- !file.exists( system.file("include/Eigen",package="TMB") )
   useContrib   <-  file.exists( system.file("include/contrib",package="TMB") )
-  ppflags <- paste(paste0("-I",system.file("include",package="TMB")),
-                   paste0("-I",system.file("include",package="RcppEigen"))[useRcppEigen],
-                   paste0("-I",system.file("include/contrib",package="TMB"))[useContrib],
+  ppflags <- paste(paste0("-I",qsystem.file("include",package="TMB")),
+                   paste0("-I",qsystem.file("include",package="RcppEigen"))[useRcppEigen],
+                   paste0("-I",qsystem.file("include/contrib",package="TMB"))[useContrib],
                    "-DTMB_SAFEBOUNDS"[safebounds],
                    paste0("-DLIB_UNLOAD=R_unload_",libname)[safeunload],
                    "-DWITH_LIBTMB"[libtmb],
